import { shouldBlockCrawler, extractUserAgent } from './core.js';

describe('shouldBlockCrawler', () => {
  test('should block AI crawlers by default', () => {
    const result = shouldBlockCrawler('GPTBot/1.0');
    expect(result.isBlocked).toBe(true);
    expect(result.crawlerType).toBe('ai');
  });

  test('should not block SEO crawlers by default', () => {
    const result = shouldBlockCrawler('Googlebot/2.1');
    expect(result.isBlocked).toBe(false);
    expect(result.crawlerType).toBe('seo');
  });

  test('should respect whitelist', () => {
    const result = shouldBlockCrawler('GPTBot/1.0', {
      whitelist: [/GPTBot/i]
    });
    expect(result.isBlocked).toBe(false);
  });

  test('should block custom patterns', () => {
    const result = shouldBlockCrawler('CustomBot/1.0', {
      customBlocked: [/CustomBot/i]
    });
    expect(result.isBlocked).toBe(true);
    expect(result.crawlerType).toBe('custom');
  });

  test('should allow regular browsers', () => {
    const result = shouldBlockCrawler('Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36');
    expect(result.isBlocked).toBe(false);
    expect(result.crawlerType).toBe(null);
  });
});

describe('extractUserAgent', () => {
  test('should extract from Express-style headers', () => {
    const headers = { 'user-agent': 'TestBot/1.0' };
    const userAgent = extractUserAgent(headers);
    expect(userAgent).toBe('TestBot/1.0');
  });

  test('should extract from SvelteKit-style headers', () => {
    const headers = {
      get: (name: string) => name === 'user-agent' ? 'TestBot/1.0' : null
    };
    const userAgent = extractUserAgent(headers);
    expect(userAgent).toBe('TestBot/1.0');
  });

  test('should handle missing user agent', () => {
    const headers = {};
    const userAgent = extractUserAgent(headers);
    expect(userAgent).toBe('');
  });
}); 