export interface CrawlerConfig {
  /** Block AI crawlers (default: true) */
  blockAI?: boolean;
  /** Block SEO crawlers (default: false) */
  blockSEO?: boolean;
  /** Custom response message when blocking crawlers (default: "Access denied") */
  message?: string;
  /** HTTP status code to return when blocking (default: 403) */
  statusCode?: number;
  /** Additional user agents to block (regex patterns) */
  customBlocked?: (string | RegExp)[];
  /** User agents to always allow (takes precedence over blocking) */
  whitelist?: (string | RegExp)[];
  /** Custom response headers to set when blocking */
  headers?: Record<string, string>;
  /** Enable debug logging (default: false) */
  debug?: boolean;
}

export interface CrawlerDetectionResult {
  isBlocked: boolean;
  crawlerType: 'ai' | 'seo' | 'custom' | null;
  userAgent: string;
  matchedPattern?: string | RegExp;
}

// Header types for different environments
export type HeadersLike = 
  | Record<string, string | string[] | undefined>  // Express-style
  | { get(name: string): string | null };          // Web API Headers-style 